==> mysql-5.7_5.7.11.orig.tar.gz: mysql-5.7.11/storage/ndb/test/crund/src/com/mysql/cluster/crund/Load.java <==
/*
  Copyright (c) 2010, 2013, Oracle and/or its affiliates. All rights reserved.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License as published by
  the Free Software Foundation; version 2 of the License.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

package com.mysql.cluster.crund;

import java.io.PrintWriter;

abstract public class Load {
    // console
    static protected final PrintWriter out = Driver.out;
    static protected final PrintWriter err = Driver.err;

    // short descriptor
    protected String name;
    public String getName() {
        return name;
    }

    // intializers/finalizers
    abstract public void init() throws Exception;
    abstract public void close() throws Exception;

    // datastore operations
    abstract public void initConnection() throws Exception;
    abstract public void closeConnection() throws Exception;
    abstract public void clearData() throws Exception;

    // benchmark operations
    abstract public void runOperations(int nOps) throws Exception;
}

==> mysql-5.7.36.tar.gz: mysql-5.7.36/storage/ndb/test/crund/src/com/mysql/cluster/crund/Load.java <==
/*
  Copyright (c) 2010, 2021, Oracle and/or its affiliates.

  This program is free software; you can redistribute it and/or modify
  it under the terms of the GNU General Public License, version 2.0,
  as published by the Free Software Foundation.

  This program is also distributed with certain software (including
  but not limited to OpenSSL) that is licensed under separate terms,
  as designated in a particular file or component or in included license
  documentation.  The authors of MySQL hereby grant you an additional
  permission to link the program and your derivative works with the
  separately licensed software that they have included with MySQL.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License, version 2.0, for more details.

  You should have received a copy of the GNU General Public License
  along with this program; if not, write to the Free Software
  Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA
*/

package com.mysql.cluster.crund;

import java.io.PrintWriter;

abstract public class Load {
    // console
    static protected final PrintWriter out = Driver.out;
    static protected final PrintWriter err = Driver.err;

    // short descriptor
    protected String name;
    public String getName() {
        return name;
    }

    // intializers/finalizers
    abstract public void init() throws Exception;
    abstract public void close() throws Exception;

    // datastore operations
    abstract public void initConnection() throws Exception;
    abstract public void closeConnection() throws Exception;
    abstract public void clearData() throws Exception;

    // benchmark operations
    abstract public void runOperations(int nOps) throws Exception;
}
